==> haskell-libyaml-0.1.4-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-2mIWeFloZC9JG8roGjvJ95
key:                    libyaml-0.1.4-2mIWeFloZC9JG8roGjvJ95
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    098df10785b411f0944a62ccc051eca7
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-2mIWeFloZC9JG8roGjvJ95
extra-libraries:        yaml
extra-libraries-static: yaml
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-CTNxTBwbo3PGCTtXLpLpH4
    resourcet-1.2.6-LvbunWgaFi52yDP9C6hdhe

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libyaml-0.1.4-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-19WcBbMJWhO3Ch3gK9y9y7
key:                    libyaml-0.1.4-19WcBbMJWhO3Ch3gK9y9y7
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    19641eb2296b8604413739fbe4161d4b
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-19WcBbMJWhO3Ch3gK9y9y7
extra-libraries:        yaml
extra-libraries-static: yaml
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-8kXjnDSt7SWIbXyadQmMao
    resourcet-1.2.6-K2pW9Jd2s2G3q0Rkt0XePg

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
